@@ -1,6 +1,7 @@
-module Text.Feed.Util.Tests where
+module Text.Feed.Util.Tests
+  ( feedUtilTests
+  ) where
 
-import Prelude ()
 import Prelude.Compat
 
 import Data.Time
